==> CytoMethIC_0.99.11.tar.gz: CytoMethIC/inst/doc/CytoMethIC.R <==
## ----message=FALSE, warning=FALSE, cache=TRUE, eval=FALSE---------------------
#  if (!requireNamespace("BiocManager", quietly = TRUE)) {
#    install.packages("BiocManager")
#  }
#  if (!requireNamespace("CytoMethIC", quietly = TRUE)) {
#    BiocManager::install("CytoMethIC")
#  }

## ----cyto2, message=FALSE, warning=FALSE--------------------------------------
library(CytoMethIC)
library(ExperimentHub)
library(sesame)
sesameDataCache()

## ----cyto3, result="asis", echo=FALSE-----------------------------------------
library(knitr)
kable(cmi_models[, c("ModelID", "PredictionLabelDescription")],
  caption = "CytoMethIC supported models"
)

## ----cyto4, message=FALSE-----------------------------------------------------
betas <- sesameDataGet("HM450.1.TCGA.PAAD")$betas
cmi_classify(betas, ExperimentHub()[["EH8395"]])
cmi_classify(betas, ExperimentHub()[["EH8396"]])

## ----cyto5, message=FALSE-----------------------------------------------------
betas <- sesameDataGet("HM450.1.TCGA.PAAD")$betas
cmi_classify(betas, ExperimentHub()[["EH8422"]])

## ----cyto6, message=FALSE-----------------------------------------------------
betas <- sesameDataGet("HM450.1.TCGA.PAAD")$betas
cmi_classify(betas, ExperimentHub()[["EH8421"]])

## ----cyto7, message=FALSE-----------------------------------------------------
betas <- sesameDataGet("HM450.1.TCGA.PAAD")$betas
cmi_classify(betas, ExperimentHub()[["EH8423"]])

## ----cyto8--------------------------------------------------------------------
cmi_model = readRDS(url("https://github.com/zhou-lab/CytoMethIC_models/raw/main/models/Race3_rfcTCGA_InfHum3.rds"))
betas = openSesame(sesameDataGet("EPICv2.8.SigDF")[[1]])
cmi_classify(betas, cmi_model)

## -----------------------------------------------------------------------------
sessionInfo()

==> CytoMethIC_0.99.18.tar.gz: CytoMethIC/inst/doc/CytoMethIC.R <==
## ----message=FALSE, warning=FALSE, cache=TRUE, eval=FALSE---------------------
#  if (!requireNamespace("BiocManager", quietly = TRUE)) {
#    install.packages("BiocManager")
#  }
#  if (!requireNamespace("CytoMethIC", quietly = TRUE)) {
#    BiocManager::install("CytoMethIC")
#  }

## ----cyto2, message=FALSE, warning=FALSE--------------------------------------
library(CytoMethIC)
library(ExperimentHub)
library(sesame)
sesameDataCache()

## ----cyto3, result="asis", echo=FALSE-----------------------------------------
library(knitr)
kable(cmi_models[, c("ModelID", "PredictionLabelDescription")],
  caption = "CytoMethIC supported models"
)

## ----cyto4, message=FALSE-----------------------------------------------------
cmi_classify(sesameDataGet("HM450.1.TCGA.PAAD")$betas, ExperimentHub()[["EH8395"]])
cmi_classify(sesameDataGet("HM450.1.TCGA.PAAD")$betas, ExperimentHub()[["EH8396"]])

## ----cyto5, message=FALSE-----------------------------------------------------
cmi_classify(sesameDataGet("HM450.1.TCGA.PAAD")$betas, ExperimentHub()[["EH8422"]])

## ----cyto6, message=FALSE-----------------------------------------------------
cmi_classify(sesameDataGet("HM450.1.TCGA.PAAD")$betas, ExperimentHub()[["EH8421"]])

## ----cyto7, message=FALSE-----------------------------------------------------
cmi_classify(sesameDataGet("HM450.1.TCGA.PAAD")$betas, ExperimentHub()[["EH8423"]])

## ----cyto8--------------------------------------------------------------------
cmi_model <- readRDS(url("https://github.com/zhou-lab/CytoMethIC_models/raw/main/models/Race3_rfcTCGA_InfHum3.rds"))
betas <- openSesame(sesameDataGet("EPICv2.8.SigDF")[[1]])
cmi_classify(betas, cmi_model)

## -----------------------------------------------------------------------------
sessionInfo()
